Module editor

Module editor 

Functions

open_clarification_editor
Open external editor for AI Rally clarification response Returns the user’s answer to the clarification question
open_comment_editor
Open external editor for comment input
open_file_at_line
Open external editor at a specific file and line number.
open_review_editor
Open external editor for review submission
open_suggestion_editor
Open external editor for suggestion input Returns the suggested code (without the original template comments)