Functions
- open_
clarification_ editor - Open external editor for AI Rally clarification response Returns the user’s answer to the clarification question
- open_
comment_ editor - Open external editor for comment input
- open_
file_ at_ line - Open external editor at a specific file and line number.
- open_
review_ editor - Open external editor for review submission
- open_
suggestion_ editor - Open external editor for suggestion input Returns the suggested code (without the original template comments)